C$Procedure      GETVOX ( Return the indices of voxel containing point )
 
      SUBROUTINE GETVOX ( VOXSIZ, VOXORI, NVOX, XYZ, INBOX, VOXID )
 
C$ Abstract
C
C     This subroutine returns the voxel grid indices that contains
C     a given point.
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
 
 
      IMPLICIT NONE
 
 
      LOGICAL               INBOX
      LOGICAL               RETURN
 
      INTEGER               NVOX      ( 3 )
      INTEGER               VOXID     ( 3 )
 
      DOUBLE PRECISION      VOXSIZ
      DOUBLE PRECISION      XYZ       ( 3 )
      DOUBLE PRECISION      VOXORI    ( 3 )
 
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     VOXSIZ     I   Voxel size in model units.
C     VOXORI     I   3-Vector location of the voxel grid origin
C                    in model units.
C     NVOX       I   Number of voxel in each dimension.
C     XYZ        I   Model grid coordinates of point.
C     INBOX      O   Logical value is true if point is inside voxel
C                    grid, false if not.
C     VOXID      O   3-Index of voxel location with the voxel grid.
C
C$ Detailed_Input
C
C     VOXSIZ     is a double precision scalar value giving the size of
C                each cubical voxel in model units.
C
C     VOXORI     is a double precision 3-vector indicating the location
C                of the voxel grid origin in model units.
C
C     NVOX       is an integer 3-vector giving the length of each
C                side of the voxel grid in voxel units.
C
C     XYZ        is a double precision 3-vector containing the location
C                of the point in question in model units.
C
C$ Detailed_Output
C
C     INBOX      is a logical scalar indicating whether or not the
C                point XYZ lies within the extent of the voxel grid.
C
C     VOXID      is an integer 3-vector containing the x, y, and z
C                voxel indices of the voxel containing the point.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 28-JAN-1999 (JAB)
C
C-&
 
C$ Index_Entries
C
C     We need a permuted index entry
C
C-&
 
 
C
C     Standard SPICE error handling.
C
 
      IF ( RETURN() ) THEN
         RETURN
      END IF
 
      CALL CHKIN  ( 'GETVOX' )
 
C
C     Initialize 'point in box' flag.
C
 
      INBOX = .TRUE.
 
C
C     Scale the point's coordinates to voxel grid space
C     and determine the indices of the voxel that contains it.
C
 
      VOXID(1) = 1 + IDINT(DABS(VOXORI(1)-XYZ(1))/VOXSIZ)
      VOXID(2) = 1 + IDINT(DABS(VOXORI(2)-XYZ(2))/VOXSIZ)
      VOXID(3) = 1 + IDINT(DABS(VOXORI(3)-XYZ(3))/VOXSIZ)
 
C
C     Determine if point lies inside or outside the voxel grid.
C
 
      IF(      (VOXID(1) .LT. 1) .OR. (VOXID(1) .GT. NVOX(1)) ) THEN
 
         INBOX    = .FALSE.
 
      ELSE IF( (VOXID(2) .LT. 1) .OR. (VOXID(2) .GT. NVOX(2)) ) THEN
 
         INBOX    = .FALSE.
 
      ELSE IF( (VOXID(3) .LT. 1) .OR. (VOXID(3) .GT. NVOX(3)) ) THEN
 
         INBOX    = .FALSE.
 
      END IF

C
C     Standard SPICELIB error handling.
C 
 
      CALL CHKOUT ( 'GETVOX' )
 
      RETURN
      END
