C$Procedure  INDXYZ  ( return voxel index )
 
      INTEGER FUNCTION INDXYZ ( VIXYZ, NVOX )
 
 
C     Returns the voxel index as a function of the
C     voxel's grid coordinates and the grid's dimensions.
 
C     Inputs:
C     -------
C     VIXYZ = Voxel's grid coordinates stored in a three-dimensional
C             vector.
C     NVOX  = Number of voxels in each coordinate direction.
 
C     Output:
C     -------
C     INDXYZ = Voxel index.
 
C$ Abstract
C
C     Given a voxel's grid coordinates and the voxel grid
C     dimensions, return the voxel's index.
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     VOXEL
C
C$ Declarations
 
      IMPLICIT              NONE
 
      INTEGER               NVOX   ( 3 )
      INTEGER               VIXYZ  ( 3 )
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     VIXYZ      I   Voxel's grid coordinates stored in a
C                    three-dimensional vector.
C     NVOX       I   Number of voxels in each coordinate direction.
C
C     The function returns the voxel index.
C
C$ Detailed_Input
C
C     VIXYZ      Voxel's grid coordinates stored in a
C                three-dimensional vector.
C     NVOX       Number of voxels in each coordinate direction.
C
C$ Detailed_Output
C
C     The function returns the value of the voxel index.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C     1)
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    Plate Library Version 1.0.0, 04-FEB-1999 (JAB)
C
C-&
 
C$ Index_Entries
C
C     given a voxel's coordinates return the voxel index
C
C-&
 
 
      INTEGER               NX
      INTEGER               NY
      INTEGER               NXNY
      INTEGER               NXNY2
 
      LOGICAL               RETURN
      LOGICAL               FIRST
 
      SAVE                  NX
      SAVE                  NY
      SAVE                  FIRST
      SAVE                  NXNY
      SAVE                  NXNY2
 
 
      DATA     FIRST   / .TRUE. /
 
 
C
C     Standard SPICE error handling.
C
 
      IF ( RETURN() ) THEN
         RETURN
      END IF
 
      CALL CHKIN  ( 'INDXYZ' )

C
C     Generate and save conversion coefficients.
C
 
      IF ( FIRST ) THEN
         NX = NVOX(1)
         NY = NVOX(2)
         NXNY  = NX*NY
         NXNY2 = NX*(1+NY)
         FIRST = .FALSE.
      END IF
 
C
C     Convert from voxel coordinates to voxel index.
C
 
      INDXYZ = VIXYZ(1) + VIXYZ(2)*NX + VIXYZ(3)*NXNY - NXNY2
 
C
C     Standard SPICE error handling.
C
 
      CALL CHKOUT ( 'INDXYZ' )
 
 
      RETURN
      END
