      SUBROUTINE VECMAT ( V1, V2, MATROT )
 
C
C     Given two vectors, return the axis of rotation,
C     angle of rotation and rotation matrix that rotates
C     a vector pointing along V1 to one pointing along V2.
C
 
      IMPLICIT              NONE
 
      INTEGER               I
      INTEGER               J
 
      LOGICAL               ISROT
 
      DOUBLE PRECISION      PI
      DOUBLE PRECISION      VSEP
      DOUBLE PRECISION      ANGLE
      DOUBLE PRECISION      U1      ( 3 )
      DOUBLE PRECISION      U2      ( 3 )
      DOUBLE PRECISION      V1      ( 3 )
      DOUBLE PRECISION      V2      ( 3 )
      DOUBLE PRECISION      AXROT   ( 3 )
      DOUBLE PRECISION      MATROT  ( 3, 3 )
 
 
C
C     Get the unit vectors.
C
 
      CALL VHAT ( V1, U1 )
      CALL VHAT ( V2, U2 )
 
C
C     Determine the angle between V1 and V2.
C
 
      ANGLE = VSEP ( U1, U2 )
 
C
C     Take care of cases where ANGLE is 0 or 180 degrees.
C
 
      IF ( ANGLE .EQ. PI() ) THEN
 
         DO I = 1, 3
            DO J = 1, 3
               MATROT(I,J) = 0.D0
               IF ( I .EQ. J ) THEN
                  MATROT(I,I) = -1.D0
               END IF
            END DO
         END DO
 
      ELSE IF ( ANGLE .EQ. 0.D0 ) THEN
 
         DO I = 1, 3
            DO J = 1, 3
               MATROT(I,J) = 0.D0
               IF ( I .EQ. J ) THEN
                  MATROT(I,I) = 1.D0
               END IF
            END DO
         END DO
 
      ELSE
 
 
C
C     Determine the axis of rotation.
C
 
         CALL UCRSS ( U1, U2, AXROT )
 
      END IF
 
C
C     Determine the rotation matrix.
C
 
      CALL AXISAR ( AXROT, ANGLE, MATROT )
 
C
C     Check that this is really a rotation matrix.
C
 
      IF ( .NOT. ISROT ( MATROT, 1.D-6, 1.D-6 ) ) THEN
          WRITE(*,*) 'vecmat: not a rotation matrix'
          WRITE(*,*) MATROT
          STOP
      END IF
 
      RETURN
      END
